# setup.py
# -*- coding: utf8 -*-
# vim:fileencoding=utf8 ai ts=4 sts=4 et sw=4

"""Setuptools setup.py file for Skaapsteker."""

from setuptools import setup, find_packages

try:
    import py2exe
except ImportError:
    pass

VERSION_STR = "0.1.1"

setup   (   # Metadata
            name = "nine-tales",
            version = VERSION_STR,
            description = "Nine Tales of the Kitsune: Platformer for PyWeek 12",

            author = ("Adrianna Pinska, Anna Malczyk, Jeremy Thurgood, "
                      "Neil Muller, Oliver Hambsch, Simon Cross, Stefano Rivera"),
            author_email = "",

            maintainer = "Skaapsteker Team",
            maintainer_email = "ctpug@googlegroups.com",

            url = "http://ctpug.org.za/",
            download_url = "https://ctpug.org.za/hg/skaapsteker/",

            license = "MIT",

            classifiers = [
                  'Development Status :: 4 - Beta',
                  'Environment :: MacOS X',
                  'Environment :: Win32 (MS Windows)',
                  'Environment :: X11 Applications',
                  'Intended Audience :: End Users/Desktop',
                  'License :: OSI Approved :: MIT License',
                  'Natural Language :: English',
                  'Operating System :: Microsoft :: Windows',
                  'Operating System :: POSIX',
                  'Operating System :: MacOS :: MacOS X',
                  'Programming Language :: Python :: 2.5',
                  'Programming Language :: Python :: 2.6',
                  'Topic :: Games/Entertainment :: Role-Playing',
                  'Topic :: Games/Entertainment :: Arcade',
             ],

            platforms = [
                  'Linux',
                  'Mac OS X',
                  'Windows',
            ],

            # Dependencies
            install_requires = [],

            # Files
            packages = find_packages(),
            scripts = [
                  'scripts/skaapsteker'
            ],

            # py2exe
            console = ['scripts/testconsole.py'],
            windows = [{
                'script': 'scripts/skaapsteker',
                'icon_resources': [(0, "data/icons/program/icon.ico")],
            }],
            app = ['scripts/skaapsteker'],
            options = {
            'py2exe': {
                'skip_archive': 1,
                'dist_dir': 'dist/nine-tales-%s' % VERSION_STR,
                'packages': [
                    'logging', 'encodings', 'skaapsteker',
                ],
                'includes': [
                    # pygame
                    'pygame',
                ],
                'excludes': [
                    'numpy',
                ],
                'ignores': [
                    # all database modules
                    'pgdb', 'Sybase', 'adodbapi',
                    'kinterbasdb', 'psycopg', 'psycopg2', 'pymssql',
                    'sapdb', 'pysqlite2', 'sqlite', 'sqlite3',
                    'MySQLdb', 'MySQLdb.connections',
                    'MySQLdb.constants.CR', 'MySQLdb.constants.ER',
                    # old datetime equivalents
                    'DateTime', 'DateTime.ISO',
                    'mx', 'mx.DateTime', 'mx.DateTime.ISO',
                    # email modules
                    'email.Generator', 'email.Iterators', 'email.Utils',
                ],
            },
            'py2app': {
                'app': ['run_game.py'],
                'argv_emulation': True,
                'iconfile': 'data/icons/program/icon.icns',
#                 'dist_dir': 'dist/nine-tales-%s' % VERSION_STR,
#                 'bdist_base': 'build/bdist',
                'packages': [
                    'logging', 'encodings', 'pygame', 'skaapsteker', 'data',
                ],
                'excludes': ['numpy'],
            }},
            data_files = [
                # 'COPYRIGHT',
                'LICENSE.txt',
                'README.txt',
            ],
            include_package_data = True
        )
